@@ -70,6 +70,28 @@
 
 extern unsigned int buttonModifierMasks[];
 
+
+static void AcceptPrematureClientMessage (XClientMessageEvent *clientEvent)
+{
+    XChangeProperty (DISPLAY, clientEvent->window,
+		     wmGD.xa_PREMATURE_XCLIENTMESSAGEEVENT_LIST,
+		     wmGD.xa_PREMATURE_XCLIENTMESSAGEEVENT_LIST, 8,
+		     PropModeAppend, (unsigned char *) clientEvent,
+		     sizeof(XClientMessageEvent));
+}
+
+static void HandleVisibilityNotify (ClientData *pCD,
+				    XVisibilityEvent *visibilityEvent)
+{
+    if (pCD == pCD->pSD->topClient &&
+	visibilityEvent->state != VisibilityUnobscured)
+	Do_Raise (pCD, NULL, STACK_NORMAL);
+    else if (pCD == pCD->pSD->bottomClient &&
+	     visibilityEvent->state != VisibilityFullyObscured)
+	Do_Lower (pCD, NULL, STACK_NORMAL);
+}
+
+
 
 /*************************************<->*************************************
  *
@@ -510,7 +532,6 @@ Boolean HandleEventsOnSpecialWindows (XEvent *pEvent)
 {
     Boolean dispatchEvent = True;
     WmScreenData *pSD;
-    ClientData *pCD;
 
 
     /*
@@ -610,19 +631,7 @@ Boolean HandleEventsOnSpecialWindows (XEvent *pEvent)
 
 	    case ClientMessage:
 	    {
-		if (pCD = InitClientData (pEvent->xclient.window)) {
-		    XClientMessageEvent *clientEvent = pEvent;
-
-		    if (clientEvent->message_type ==
-			wmGD.xa__NET_WM_FULLSCREEN_MONITORS)
-		    {
-			ProcessNetWmFullscreenMonitors (pCD,
-			    clientEvent->data.l[0], clientEvent->data.l[1],
-			    clientEvent->data.l[2], clientEvent->data.l[3]);
-
-			dispatchEvent = False;
-		    }
-		}
+		AcceptPrematureClientMessage ((XClientMessageEvent *)pEvent);
 		break;
 	    }
 	}
@@ -701,6 +710,12 @@ Boolean HandleEventsOnClientWindow (ClientData *pCD, XEvent *pEvent)
 	    break;
 	}
 
+	case VisibilityNotify:
+	{
+	    HandleVisibilityNotify (pCD, (XVisibilityEvent *)pEvent);
+	    doXtDispatchEvent = False;
+	    break;
+	}
     }
 
     return (doXtDispatchEvent);
@@ -746,18 +761,6 @@ void HandleCPropertyNotify (ClientData *pCD, XPropertyEvent *propertyEvent)
 	    break;
 	}
 	
-        case XA_WM_NAME:
-	{
-	    ProcessWmWindowTitle (pCD, FALSE /*not first time*/);
-	    break;
-	}
-	
-        case XA_WM_ICON_NAME:
-	{
-	    ProcessWmIconTitle (pCD, FALSE /*not first time*/);
-	    break;
-	}
-	
         case XA_WM_CLASS:
 	{
 
@@ -866,13 +869,15 @@ void HandleCPropertyNotify (ClientData *pCD, XPropertyEvent *propertyEvent)
 		ProcessMwmHints (pCD);
 		SetClientOffset (pCD);
 	    }
-	    else if (propertyEvent->atom == wmGD.xa__NET_WM_NAME)
+	    else if (propertyEvent->atom == XA_WM_NAME ||
+		     propertyEvent->atom == wmGD.xa__NET_WM_NAME)
 	    {
-		ProcessNetWmName (pCD);
+		ProcessWmWindowTitle (pCD, FALSE /*not first time*/);
 	    }
-	    else if (propertyEvent->atom == wmGD.xa__NET_WM_ICON_NAME)
+	    else if (propertyEvent->atom == XA_WM_ICON_NAME ||
+		     propertyEvent->atom == wmGD.xa__NET_WM_ICON_NAME)
 	    {
-		ProcessNetWmIconName (pCD);
+		ProcessWmIconTitle (pCD, FALSE /*not first time*/);
 	    }
 	    break;
 	}
@@ -2608,6 +2613,13 @@ void HandleClientMessage (ClientData *pCD, XClientMessageEvent *clientEvent)
 	ProcessNetWmFullscreenMonitors (pCD,
 	    clientEvent->data.l[0], clientEvent->data.l[1],
 	    clientEvent->data.l[2], clientEvent->data.l[3]);
+
+	if (pCD->fullscreenAuto)
+	    XDeleteProperty (DISPLAY, pCD->client, clientEvent->message_type);
+	else
+	    XChangeProperty (DISPLAY, pCD->client, clientEvent->message_type,
+			     XA_CARDINAL, 32, PropModeReplace,
+			     (unsigned char *) clientEvent->data.l, 4);
     }
     else if (clientEvent->message_type == wmGD.xa__NET_WM_STATE)
     {
