@@ -23,29 +23,13 @@
  * Floor, Boston, MA 02110-1301 USA
  */
 
-#ifndef _Dt_WmEwmh_h_
-#define _Dt_WmEwmh_h_
-
-#define _NET_WM_STATE_REMOVE 0
-#define _NET_WM_STATE_ADD 1
-#define _NET_WM_STATE_TOGGLE 2
-
-#define _XA__NET_SUPPORTED "_NET_SUPPORTED"
-#define _XA__NET_SUPPORTING_WM_CHECK "_NET_SUPPORTING_WM_CHECK"
-#define _XA__NET_WM_NAME "_NET_WM_NAME"
-#define _XA__NET_WM_ICON_NAME "_NET_WM_ICON_NAME"
-#define _XA__NET_WM_FULLSCREEN_MONITORS "_NET_WM_FULLSCREEN_MONITORS"
-#define _XA__NET_WM_STATE "_NET_WM_STATE"
-#define _XA__NET_WM_STATE_FULLSCREEN "_NET_WM_STATE_FULLSCREEN"
-#define _XA__NET_WM_STATE_MAXIMIZED_VERT "_NET_WM_STATE_MAXIMIZED_VERT"
-#define _XA__NET_WM_STATE_MAXIMIZED_HORZ "_NET_WM_STATE_MAXIMIZED_HORZ"
+#ifndef WMEWMH_H
+#define WMEWMH_H
 
 void ProcessNetWmFullscreenMonitors (ClientData *pCD,
-    long top, long bottom, long left, long right);
+    int top, int bottom, int left, int right);
 void ProcessNetWmState (ClientData *pCD, long action,
-    long firstProperty, long secondProperty);
-void ProcessNetWmName (ClientData *pCD);
-void ProcessNetWmIconName (ClientData *pCD);
+    Atom firstProperty, Atom secondProperty);
 void SetupWmEwmh (void);
 
-#endif /* _Dt_WmEwmh_h_ */
+#endif
