@@ -109,6 +109,9 @@ extern Pixel		FPselectcolor;
 
 /* ICCC atom names: */
 
+#define _XA_PREMATURE_XCLIENTMESSAGEEVENT_LIST \
+	"PREMATURE_XCLIENTMESSAGEEVENT_LIST"
+
 #define _XA_WM_STATE		"WM_STATE"
 #define _XA_WM_PROTOCOLS	"WM_PROTOCOLS"
 #define _XA_WM_CHANGE_STATE	"WM_CHANGE_STATE"
@@ -117,6 +120,26 @@ extern Pixel		FPselectcolor;
 #define _XA_WM_TAKE_FOCUS	"WM_TAKE_FOCUS"
 #define _XA_WM_COLORMAP_WINDOWS	"WM_COLORMAP_WINDOWS"
 
+/* EWMH atom names: */
+
+#define _NET_WM_STATE_REMOVE 0
+#define _NET_WM_STATE_ADD 1
+#define _NET_WM_STATE_TOGGLE 2
+
+#define _XA__NET_SUPPORTED "_NET_SUPPORTED"
+#define _XA__NET_SUPPORTING_WM_CHECK "_NET_SUPPORTING_WM_CHECK"
+#define _XA__NET_WM_NAME "_NET_WM_NAME"
+#define _XA__NET_WM_ICON_NAME "_NET_WM_ICON_NAME"
+#define _XA__NET_WM_VISIBLE_NAME "_NET_WM_VISIBLE_NAME"
+#define _XA__NET_WM_VISIBLE_ICON_NAME "_NET_WM_VISIBLE_ICON_NAME"
+#define _XA__NET_WM_FULLSCREEN_MONITORS "_NET_WM_FULLSCREEN_MONITORS"
+#define _XA__NET_WM_STATE "_NET_WM_STATE"
+#define _XA__NET_WM_STATE_MAXIMIZED_VERT "_NET_WM_STATE_MAXIMIZED_VERT"
+#define _XA__NET_WM_STATE_MAXIMIZED_HORZ "_NET_WM_STATE_MAXIMIZED_HORZ"
+#define _XA__NET_WM_STATE_FULLSCREEN "_NET_WM_STATE_FULLSCREEN"
+#define _XA__NET_WM_STATE_ABOVE "_NET_WM_STATE_ABOVE"
+#define _XA__NET_WM_STATE_BELOW "_NET_WM_STATE_BELOW"
+
 /* window manager exit value on fatal errors: */
 #define WM_ERROR_EXIT_VALUE	1
 
@@ -1106,6 +1129,19 @@ typedef struct _FrameInfo
 
 } FrameInfo;
 
+/**
+ * @brief Specific data for instant title dialog
+ */
+typedef struct _InstantTitleData
+{
+    Boolean		widgetsInitialized;
+    struct _ClientData	*pCDforClient;
+    Context		contextForClient;
+    Widget		dialogShellW;
+    Widget		dialogBoxW;
+    Widget		formW;
+    Widget		textFieldW;
+} InstantTitleData, *PtrInstantTitleData;
 
 
 /*************************************<->*************************************
@@ -1132,6 +1168,7 @@ typedef struct _WmScreenData
     Widget      confirmboxW[4];
     Widget	wPanelist;		/* panel object */
     WsPresenceData	presence;	/* workspace presence dialog*/
+    InstantTitleData instantTitleData;	/* instant title dialog */
     Widget	switcherW;		/* workspace switcher */
     Widget	switcherShellW;		/* shell for ws switcher */
     Window	wmWorkspaceWin;		/* holds wm properties */
@@ -1290,6 +1327,9 @@ typedef struct _WmScreenData
     DtSvcHandle	hWsm;		/* WORKSPACEMGR message handle */
     Boolean	bMarqueeSelectionInitialized;
 
+    /* top and bottom clients */
+    struct _ClientData	*topClient;
+    struct _ClientData	*bottomClient;
 } WmScreenData;
 
 typedef struct _WmScreenData *PtrScreenData;
@@ -1310,6 +1350,8 @@ typedef struct _WmScreenData *PtrScreenData;
 /*
 #define ICON_DEFAULT_TITLE(pcd) ((pcd)->iconDefaultTitle)
 */
+#define ICON_DISPLAY_TITLE(pcd) \
+	((pcd)->instantTitle ? (pcd)->instantTitle : (pcd)->iconTitle)
 #define ICON_DECORATION(pcd) ((pcd)->pSD->iconDecoration)
 #define ICON_HEIGHT(pcd) ((pcd)->pSD->iconHeight)
 #define ICON_WIDTH(pcd) ((pcd)->pSD->iconWidth)
@@ -1465,6 +1507,8 @@ typedef struct _WmWorkspaceData *PtrWorkspaceData;
 /*
 #define CLIENT_DEFAULT_TITLE(pcd) ((pcd)->pSD->clientDefaultTitle)
 */
+#define CLIENT_DISPLAY_TITLE(pcd) \
+	((pcd)->instantTitle ? (pcd)->instantTitle : (pcd)->clientTitle)
 #define MAX_MAX_SIZE(pcd) ((pcd)->pSD->maximumMaximumSize)
 #define SHOW_RESIZE_CURSORS(pcd) ((pcd)->pSD->resizeCursors)
 #define JOIN_BEVEL(pcd) ((pcd)->pSD->joinBevel)
@@ -1630,12 +1674,13 @@ typedef struct _ClientData
     Window	clientBaseWin;			/* for matte & reparenting */
     int		xBorderWidth;			/* original X border width */
     FrameInfo	frameInfo;			/* frame geometry data */
-    Boolean	isFullscreen;			/* True => fullscreen */
-    Boolean	monitorSizeIsSet;		/* True => X, Y, W, H is set */
-    int		monitorX;			/* monitor X loc */
-    int		monitorY;			/* monitor Y loc */
-    int		monitorWidth;			/* monitor width */
-    int		monitorHeight;			/* monitor height */
+    Boolean	fullscreen;			/* fullscreen flag */
+    Boolean	fullscreenAuto;			/* False => set by client */
+    int		fullscreenX;			/* fullscreen X loc */
+    int		fullscreenY;			/* fullscreen Y loc */
+    int		fullscreenWidth;		/* fullscreen width */
+    int		fullscreenHeight;		/* fullscreen height */
+    XmString	instantTitle;			/* instant title */
 
     /* client window frame graphic data: */
 
@@ -1834,7 +1879,6 @@ typedef struct _WmGlobalData
     Widget	topLevelW1;             /* from which WM components hang */
     Boolean     confirmDialogMapped;    /* confirm dialog is mapped */
     XtAppContext	mwmAppContext;	/* application context for mwm */
-    XContext	tmpWindowContextType;	/* temporary window context */
     XContext	windowContextType;	/* window context for XSaveContext */
     XContext	screenContextType;	/* screen context for XSaveContext */
 #ifndef	IBM_169380
@@ -1918,6 +1962,8 @@ typedef struct _WmGlobalData
 
     /* atoms used in inter-client communication: */
 
+    Atom	xa_PREMATURE_XCLIENTMESSAGEEVENT_LIST;
+
     Atom	xa_WM_STATE;
     Atom	xa_WM_PROTOCOLS;
     Atom	xa_WM_CHANGE_STATE;
@@ -1939,11 +1985,15 @@ typedef struct _WmGlobalData
     Atom	xa_UTF8_STRING;
     Atom	xa__NET_WM_NAME;
     Atom	xa__NET_WM_ICON_NAME;
+    Atom	xa__NET_WM_VISIBLE_NAME;
+    Atom	xa__NET_WM_VISIBLE_ICON_NAME;
     Atom	xa__NET_WM_FULLSCREEN_MONITORS;
     Atom	xa__NET_WM_STATE;
-    Atom	xa__NET_WM_STATE_FULLSCREEN;
     Atom	xa__NET_WM_STATE_MAXIMIZED_VERT;
     Atom	xa__NET_WM_STATE_MAXIMIZED_HORZ;
+    Atom	xa__NET_WM_STATE_FULLSCREEN;
+    Atom	xa__NET_WM_STATE_ABOVE;
+    Atom	xa__NET_WM_STATE_BELOW;
 
     /* atoms used for workspace management: */
 
