@@ -411,7 +411,6 @@ void InitWmGlobal (int argc, char *argv [], char *environ [])
      * Do (pre-toolkit) initialization:
      */
 
-    wmGD.tmpWindowContextType = XUniqueContext ();
     wmGD.windowContextType = XUniqueContext ();
     wmGD.screenContextType = XUniqueContext ();
 #ifndef	IBM_169380
@@ -1240,6 +1239,7 @@ InitWmScreen (WmScreenData *pSD, int sNum)
     pSD->presence.shellW = NULL;
     pSD->presence.onScreen = False;
     pSD->presence.userDismissed = True;
+    pSD->instantTitleData.widgetsInitialized = False;
     pSD->workspaceList = NULL;
     pSD->numWorkspaces = 0;
     pSD->numWsDataAllocated = 0;
@@ -1272,6 +1272,9 @@ InitWmScreen (WmScreenData *pSD, int sNum)
     pSD->iconBoxControl = False;
     pSD->displayResolutionType = _DtGetDisplayResolution(DISPLAY, sNum);
 
+    pSD->topClient = NULL;
+    pSD->bottomClient = NULL;
+
     /*
      *  We've got display resolution type--now, let's get color
      *  characteristics.
