@@ -50,6 +50,7 @@
 #include "WmIDecor.h"
 #include "WmIconBox.h"
 #include "WmImage.h"
+#include "WmInstantTitle.h"
 #include "WmKeyFocus.h"
 #include "WmPanelP.h"	/* typedef needed in WmManage.h */
 #include <Dt/Message.h>
@@ -97,6 +98,34 @@ static void CheckPushRecallClient (ClientData *pCD);
  */
 
 
+static void ApplyPrematureClientMessages (ClientData *pCD)
+{
+    unsigned long i, nitems, leftover;
+    int actualFormat;
+    Atom actualType;
+    Atom property = wmGD.xa_PREMATURE_XCLIENTMESSAGEEVENT_LIST;
+    XClientMessageEvent *messages = NULL;
+
+    if (!HasProperty (pCD, property)) goto err;
+
+    if (XGetWindowProperty (DISPLAY, pCD->client, property, 0L, 1000000L, True,
+			    property, &actualType, &actualFormat, &nitems,
+			    &leftover, (unsigned char **)&messages) != Success)
+	goto err;
+
+    if (actualType != property) goto err;
+
+    nitems /= sizeof (XClientMessageEvent);
+
+    if (!nitems) goto err;
+
+    for (i = 0; i < nitems; ++i) HandleClientMessage (pCD, &messages[i]);
+
+err:
+    if (messages) XFree (messages);
+}
+
+
 
 /*************************************<->*************************************
  *
@@ -711,6 +740,11 @@ ManageWindow (WmScreenData *pSD, Window clientWindow, long manageFlags)
 		      CurrentTime, NULL, 0);
     }
 
+    ApplyPrematureClientMessages (pCD);
+
+    if (!HasProperty (pCD, wmGD.xa__NET_WM_STATE))
+	UpdateNetWmState (pCD->client, NULL, 0, _NET_WM_STATE_REMOVE);
+
     /*
      * Free the initial property list. This will force
      * reads of properties that change after the initial
@@ -887,6 +921,8 @@ void WithdrawWindow (ClientData *pCD)
     int i;
     XWindowChanges xwc;
 
+    if (pCD->pSD->topClient == pCD) pCD->pSD->topClient = NULL;
+    if (pCD->pSD->bottomClient == pCD) pCD->pSD->bottomClient = NULL;
 
     /*
      * Put the client window into a withdrawn state:
@@ -957,6 +993,8 @@ void WithdrawWindow (ClientData *pCD)
 	pCD->pSD->presence.pCDforClient = NULL;
     }
 
+    InstantTitleHideDialog (pCD);
+
     /*
      * Check to see if the window is being unmanaged because the window
      * was destroyed.
@@ -1009,6 +1047,8 @@ void WithdrawWindow (ClientData *pCD)
 	}
 
 	XDeleteProperty (DISPLAY, pCD->client, wmGD.xa__NET_WM_STATE);
+	XDeleteProperty (DISPLAY, pCD->client,
+			 wmGD.xa_PREMATURE_XCLIENTMESSAGEEVENT_LIST);
 	XUnmapWindow (DISPLAY, pCD->client);
 	XReparentWindow (DISPLAY, pCD->client, ROOT_FOR_CLIENT(pCD), x, y);
 
@@ -1136,6 +1176,11 @@ void WithdrawWindow (ClientData *pCD)
 	XmStringFree (pCD->iconTitle);
     }
 
+    if (pCD->instantTitle)
+    {
+	XmStringFree (pCD->instantTitle);
+    }
+
     if (pCD->clientCmapCount > 0)
     {
 	for (i = 0; i < pCD->clientCmapCount; i++)
