@@ -36,7 +36,9 @@
 
 #include "WmGlobal.h"
 #include "WmICCC.h"
+#include <limits.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <Dt/WsmP.h>
 #include <X11/Xatom.h>
 #include <Xm/AtomMgr.h>
@@ -1887,6 +1889,114 @@ HasProperty (
 
 } /* END OF FUNCTION HasProperty */
 
+/**
+ * @brief This function calls XGetWindowProperty to get the UTF8_STRING
+ *        property.
+ *
+ * @param display
+ * @param w
+ * @param property
+ *
+ * @return A string or NULL.
+ */
+char *GetUtf8String (Display *display, Window w, Atom property)
+{
+    int actualFormat;
+    char *propReturn;
+    unsigned long nitems, leftover;
+    Atom actualType;
+    Atom reqType = wmGD.xa_UTF8_STRING;
 
+    if (XGetWindowProperty (display, w, property, 0L, USHRT_MAX, False, reqType,
+			    &actualType, &actualFormat, &nitems, &leftover,
+			    (unsigned char **) &propReturn) != Success)
+	goto err;
 
+    if (!nitems) goto err;
+    if (actualType != reqType) goto err;
 
+    return propReturn;
+
+err:
+    if (propReturn) XFree (propReturn);
+    return NULL;
+}
+
+/**
+ * @brief This function calls XChangeProperty to set the UTF8_STRING property.
+ *
+ * @param display
+ * @param w
+ * @param property
+ * @param s
+ */
+void SetUtf8String (Display *display, Window w, Atom property, const char *s)
+{
+    size_t len;
+
+    if (!(s && s[0])) return;
+
+    len = strnlen (s, USHRT_MAX);
+
+    XChangeProperty (display, w, property, wmGD.xa_UTF8_STRING, 8,
+		     PropModeReplace, (unsigned char *)s, len);
+}
+
+/**
+ * @brief This function updates _NET_WM_STATE property.
+ *
+ * @param window
+ * @param states
+ * @param nstates
+ * @param action
+ */
+void UpdateNetWmState (Window window, Atom *states, unsigned long nstates,
+		       long action)
+{
+    int i, j, actualFormat;
+    unsigned long nold, leftover;
+    Atom actualType;
+    unsigned long nnew = 0;
+    Atom type = wmGD.xa__NET_WM_STATE;
+    Atom *oldStates = NULL;
+    Atom *newStates = NULL;
+
+    if (!states) nstates = 0;
+
+    if (!(XGetWindowProperty (DISPLAY, window, type, 0L, 1000000L, False,
+			      XA_ATOM, &actualType, &actualFormat, &nold,
+			      &leftover, (unsigned char **) &oldStates)
+	== Success && actualType == XA_ATOM)) nold = 0;
+
+    newStates = malloc ((1 + nstates + nold) * sizeof (Atom));
+
+    if (!newStates) goto done;
+
+    for (i = 0; i < nold; ++i)
+    {
+	Atom oldState = oldStates[i];
+	for (j = 0; j < nstates; ++j) if (oldState == states[j]) break;
+	if (j >= nstates) newStates[nnew++] = oldState;
+    }
+
+    if (action == _NET_WM_STATE_ADD)
+    {
+	for (i = 0; i < nstates; ++i) newStates[nnew++] = states[i];
+    }
+    else if (action == _NET_WM_STATE_TOGGLE)
+    {
+	for (i = 0; i < nstates; ++i)
+	{
+	    Atom state = states[i];
+	    for (j = 0; j < nold; ++j) if (state == oldStates[j]) break;
+	    if (j >= nold) newStates[nnew++] = state;
+	}
+    }
+
+    XChangeProperty (DISPLAY, window, type, XA_ATOM, 32, PropModeReplace,
+		     (unsigned char *) newStates, nnew);
+
+done:
+    if (oldStates) XFree (oldStates);
+    if (newStates) free (newStates);
+}
