@@ -56,7 +56,6 @@
 #include "WmCDecor.h"
 #include "WmCPlace.h"
 #include "WmError.h"
-#include "WmEwmh.h"
 #include "WmIDecor.h"
 #include "WmIPlace.h"
 #include "WmIconBox.h"
@@ -90,7 +89,7 @@ WmWorkspaceData *pIconBoxInitialWS;
 
 /*************************************<->*************************************
  *
- *  InitClientData (clientWindow)
+ *  GetClientInfo (pSD, clientWindow, manageFlags)
  *
  *
  *  Description:
@@ -101,8 +100,12 @@ WmWorkspaceData *pIconBoxInitialWS;
  *
  *  Inputs:
  *  ------
+ *  pSD = pointer to screen data for screen that client lives in
+ *
  *  clientWindow = window id for the client window that is to be managed
  *
+ *  manageFlags = flags that indicate wm state info
+ *
  *
  *  Outputs:
  *  -------
@@ -112,23 +115,13 @@ WmWorkspaceData *pIconBoxInitialWS;
  *************************************<->***********************************/
 
 ClientData *
-InitClientData (Window clientWindow)
+GetClientInfo (WmScreenData *pSD, Window clientWindow, long manageFlags)
+
 {
     int i;
     ClientData *pCD;
+    XSetWindowAttributes sAttributes;
 
-    if (!XFindContext (DISPLAY, clientWindow, wmGD.windowContextType,
-			    (caddr_t *)&pCD))
-    {
-	XDeleteContext(DISPLAY, clientWindow, wmGD.tmpWindowContextType);
-	return (pCD);
-    }
-
-    if (!XFindContext (DISPLAY, clientWindow, wmGD.tmpWindowContextType,
-			    (caddr_t *)&pCD))
-    {
-	return (pCD);
-    }
 
     /*
      * Allocate and initialize a client data structure:
@@ -141,15 +134,13 @@ InitClientData (Window clientWindow)
 	return (NULL);
     }
 
-    XSaveContext (DISPLAY, clientWindow, wmGD.tmpWindowContextType,
-		    (caddr_t)pCD);
-
 
     /*
      * Initialize the data structure:
      */
 
     pCD->client = clientWindow;
+    pCD->clientID = ++(pSD->clientCounter);
     pCD->clientFlags = WM_INITIALIZATION;
     pCD->iconFlags = 0;
     pCD->thisIconBox = NULL;
@@ -210,6 +201,7 @@ InitClientData (Window clientWindow)
     pCD->maxWidth = pCD->maxWidthLimit = BIGSIZE;
     pCD->maxHeight = pCD->maxHeightLimit = BIGSIZE;
     pCD->maxConfig = FALSE;
+    pCD->pSD = pSD;
     pCD->dataType = CLIENT_DATA_TYPE;
     pCD->window_status = 0L;
 
@@ -219,60 +211,13 @@ InitClientData (Window clientWindow)
 
     pCD->smClientID = (String)NULL;
 
-    pCD->isFullscreen = False;
-    pCD->monitorSizeIsSet = False;
+    pCD->fullscreen = False;
+    pCD->fullscreenAuto = True;
+
+    pCD->instantTitle = NULL;
 
     for (i = 0; i < STRETCH_COUNT; ++i) pCD->clientStretchWin[i] = (Window)0L;
 
-    return (pCD);
-} /* END OF FUNCTION InitClientData */
-
-
-
-/*************************************<->*************************************
- *
- *  GetClientInfo (pSD, clientWindow, manageFlags)
- *
- *
- *  Description:
- *  -----------
- *  This function is used to get client window data.
- *
- *
- *  Inputs:
- *  ------
- *  pSD = pointer to screen data for screen that client lives in
- *
- *  clientWindow = window id for the client window that is to be managed
- *
- *  manageFlags = flags that indicate wm state info
- *
- *
- *  Outputs:
- *  -------
- *  Return = pointer to an initialized client data structure for the
- *           specified client window
- *
- *************************************<->***********************************/
-
-ClientData *
-GetClientInfo (WmScreenData *pSD, Window clientWindow, long manageFlags)
-
-{
-    ClientData *pCD;
-    XSetWindowAttributes sAttributes;
-
-    if (!(pCD = InitClientData (clientWindow)))
-    {
-	return (NULL);
-    }
-
-    XDeleteContext(DISPLAY, clientWindow, wmGD.tmpWindowContextType);
-
-    pCD->clientID = ++(pSD->clientCounter);
-    pCD->pSD = pSD;
-
-
      /*
      * Do special processing for client windows that are controlled by
      * the window manager.
@@ -305,7 +250,8 @@ GetClientInfo (WmScreenData *pSD, Window clientWindow, long manageFlags)
      * Listen for property change events on the window so that we keep 
      * in sync with the hints.
      */
-    sAttributes.event_mask = (PropertyChangeMask | ColormapChangeMask);    
+    sAttributes.event_mask = (PropertyChangeMask | ColormapChangeMask |
+			      VisibilityChangeMask);
     XChangeWindowAttributes (DISPLAY, pCD->client, CWEventMask,
         &sAttributes);
 
@@ -420,7 +366,6 @@ GetClientInfo (WmScreenData *pSD, Window clientWindow, long manageFlags)
      */
 
     ProcessWmWindowTitle (pCD, TRUE);
-    ProcessNetWmName (pCD);
 
 
     /*
@@ -428,7 +373,6 @@ GetClientInfo (WmScreenData *pSD, Window clientWindow, long manageFlags)
      */
 
     ProcessWmIconTitle (pCD, TRUE);
-    ProcessNetWmIconName (pCD);
 
 
     /*
@@ -1411,7 +1355,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 {
     SizeHints *pNormalHints;
     long       flags;
-    int                 diff;
+    int                 diff, maxWidth, maxHeight;
     unsigned long       decoration;
     unsigned int        boxdim, tmpMin;
     unsigned int	oldWidthInc = 0, oldHeightInc = 0;
@@ -1632,6 +1576,8 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
      * maximumClientSize is either set to 'horizontal' or 'vertical'.
      */
 
+    GetMaxInfo (pCD, NULL, NULL, &maxWidth, &maxHeight);
+
     pCD->oldMaxWidth = pCD->maxWidth;
     if (pCD->maximumClientSize.width)
     {
@@ -1639,8 +1585,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 	if (IS_MAXIMIZE_HORIZONTAL(pCD))
 	{
 	    /* go to min (full screen width, max maximum width) */
-	    pCD->maxWidth = DisplayWidth (DISPLAY, SCREEN_FOR_CLIENT(pCD)) -
-				          (2 * pCD->clientOffset.x);
+	    pCD->maxWidth = maxWidth;
 
 	    /*
 	     * Hack to set max client to the current client height, maxHeight
@@ -1662,8 +1607,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 	    if (pNormalHints->max_width < 0)
 	    {
 	        /* go to min (full screen width, max maximum width) */
-		pCD->maxWidth = DisplayWidth (DISPLAY, SCREEN_FOR_CLIENT(pCD)) -
-				          (2 * pCD->clientOffset.x);
+		pCD->maxWidth = maxWidth;
 	    }
 	    else
 	    {
@@ -1676,9 +1620,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 	    if (firstTime)
 	    {
 		/* go to min (full screen width, max maximum width) */
-		pCD->maxWidth = DisplayWidth (DISPLAY,
-					      SCREEN_FOR_CLIENT(pCD)) -
-						(2 * pCD->clientOffset.x);
+		pCD->maxWidth = maxWidth;
 	    }
 	    else
 	    {
@@ -1725,9 +1667,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 	if (IS_MAXIMIZE_VERTICAL(pCD))
 	{
 	    /* go to min (full screen height, max maximum height) */
-	    pCD->maxHeight = DisplayHeight (DISPLAY, SCREEN_FOR_CLIENT(pCD)) -
-			     (pCD->clientOffset.x +
-			      pCD->clientOffset.y);
+	    pCD->maxHeight = maxHeight;
 	    /*
 	     * Hack to set max client to the current client width, maxWidth
 	     * will be kept up to date whenever the window is reconfigured
@@ -1748,10 +1688,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 	    if (pNormalHints->max_height < 0)
 	    {
 	        /* go to min (full screen height, max maximum height) */
-	        pCD->maxHeight = DisplayHeight (
-				 DISPLAY, SCREEN_FOR_CLIENT(pCD)) -
-				 (pCD->clientOffset.x +
-				  pCD->clientOffset.y);
+	        pCD->maxHeight = maxHeight;
 	    }
 	    else
 	    {
@@ -1764,10 +1701,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
 	    if (firstTime)
 	    {
 		/* go to min (full screen height, max maximum height) */
-		pCD->maxHeight = DisplayHeight (DISPLAY,
-						SCREEN_FOR_CLIENT(pCD)) -
-						  (pCD->clientOffset.x +
-						   pCD->clientOffset.y);
+		pCD->maxHeight = maxHeight;
 	    }
 	    else
 	    {
@@ -1956,8 +1890,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
     if (IS_MAXIMIZE_VERTICAL(pCD))
     {
 	/* go to min (full screen width, max maximum width) */
-	pCD->maxWidthLimit = DisplayWidth (DISPLAY, SCREEN_FOR_CLIENT(pCD)) -
-			    (2 * pCD->clientOffset.x);
+	pCD->maxWidthLimit = maxWidth;
     }
     else
     {
@@ -1983,9 +1916,7 @@ ProcessWmNormalHints (ClientData *pCD, Boolean firstTime, long manageFlags)
     if (IS_MAXIMIZE_HORIZONTAL(pCD))
     {
 	/* go to min (full screen height, max maximum height) */
-	pCD->maxHeightLimit = DisplayHeight (DISPLAY, SCREEN_FOR_CLIENT(pCD)) -
-			     (pCD->clientOffset.x +
-			      pCD->clientOffset.y);
+	pCD->maxHeightLimit = maxHeight;
     }
     else
     {
@@ -2204,16 +2135,28 @@ WmICCCMToXmString (XTextProperty *wmNameProp)
 void 
 ProcessWmWindowTitle (ClientData *pCD, Boolean firstTime)
 {
+    char *netStr;
     XTextProperty wmNameProp;
     XmString title_xms = NULL;
+    Window win = pCD->client;
+    Boolean hasWmName = HasProperty (pCD, XA_WM_NAME);
+    Boolean hasNetWmName = HasProperty (pCD, wmGD.xa__NET_WM_NAME);
 
     if ((pCD->clientDecoration & MWM_DECOR_TITLE) &&
-	(!firstTime || HasProperty (pCD, XA_WM_NAME)) &&
-	XGetWMName(DISPLAY, pCD->client, &wmNameProp))
+	(!firstTime || hasWmName || hasNetWmName))
     {
-      title_xms = WmICCCMToXmString(&wmNameProp);
-      if (wmNameProp.value)
-	XFree ((char*)wmNameProp.value);
+	if ((!firstTime || hasNetWmName) &&
+	    (netStr = GetUtf8String (DISPLAY, win, wmGD.xa__NET_WM_NAME)))
+	{
+	    title_xms = XmStringCreateLocalized (netStr);
+	    XFree (netStr);
+	}
+	else if ((!firstTime || hasWmName) &&
+		 XGetWMName(DISPLAY, win, &wmNameProp))
+	{
+	    title_xms = WmICCCMToXmString(&wmNameProp);
+	    if (wmNameProp.value) XFree ((char*)wmNameProp.value);
+	}
     }
 
     if (title_xms)
@@ -2259,6 +2202,14 @@ ProcessWmWindowTitle (ClientData *pCD, Boolean firstTime)
         }
     }
 
+    if (firstTime && pCD->instantTitle == NULL &&
+	HasProperty (pCD, wmGD.xa__NET_WM_VISIBLE_NAME) &&
+	(netStr = GetUtf8String (DISPLAY, win, wmGD.xa__NET_WM_VISIBLE_NAME)))
+    {
+	pCD->instantTitle = XmStringCreateLocalized (netStr);
+	XFree (netStr);
+    }
+
     /*
      * If this is a tear-off menu, then make sure title text is not clipped
      */
@@ -2279,7 +2230,7 @@ ProcessWmWindowTitle (ClientData *pCD, Boolean firstTime)
 	/*
 	 * Calculations derived from GetTextBox() and GetFramePartInfo()
 	 */
-	minWidth = XmStringWidth(fontList, pCD->clientTitle) +
+	minWidth = XmStringWidth(fontList, CLIENT_DISPLAY_TITLE(pCD)) +
 	    ((pCD->dtwmBehaviors & DtWM_BEHAVIOR_SUBPANEL) ? 4 : 0) +
 			    ((decor & MWM_DECOR_MENU) ? boxdim : 0) +
 			    ((decor & MWM_DECOR_MINIMIZE) ? boxdim : 0) +
@@ -2418,17 +2369,29 @@ FixSubpanelEmbeddedClientGeometry (ClientData *pCD)
 void 
 ProcessWmIconTitle (ClientData *pCD, Boolean firstTime)
 {
+  char *netStr;
   XTextProperty wmIconNameProp;
   XmString icon_xms = NULL;
+  Window win = pCD->client;
+  Boolean hasWmIconName = HasProperty (pCD, XA_WM_ICON_NAME);
+  Boolean hasNetWmIconName = HasProperty (pCD, wmGD.xa__NET_WM_ICON_NAME);
 
   if ((pCD->clientFunctions & MWM_FUNC_MINIMIZE) &&
       (pCD->transientLeader == NULL) &&
-      (!firstTime || HasProperty(pCD, XA_WM_ICON_NAME)) &&
-      XGetWMIconName (DISPLAY, pCD->client, &wmIconNameProp))
+      (!firstTime || hasWmIconName || hasNetWmIconName))
   {
-    icon_xms = WmICCCMToXmString(&wmIconNameProp);
-    if (wmIconNameProp.value)
-      XFree ((char*)wmIconNameProp.value);
+    if ((!firstTime || hasNetWmIconName) &&
+	(netStr = GetUtf8String (DISPLAY, win, wmGD.xa__NET_WM_ICON_NAME)))
+    {
+      icon_xms = XmStringCreateLocalized (netStr);
+      XFree (netStr);
+    }
+    else if ((!firstTime || hasWmIconName) &&
+	     XGetWMIconName (DISPLAY, win, &wmIconNameProp))
+    {
+      icon_xms = WmICCCMToXmString(&wmIconNameProp);
+      if (wmIconNameProp.value) XFree ((char*)wmIconNameProp.value);
+    }
   }
 
   if (icon_xms)
@@ -2463,6 +2426,14 @@ ProcessWmIconTitle (ClientData *pCD, Boolean firstTime)
     }
   }
 
+  if (firstTime && pCD->instantTitle == NULL &&
+      HasProperty (pCD, wmGD.xa__NET_WM_VISIBLE_ICON_NAME) &&
+      (netStr = GetUtf8String (DISPLAY, win,
+			       wmGD.xa__NET_WM_VISIBLE_ICON_NAME)))
+  {
+    pCD->instantTitle = XmStringCreateLocalized (netStr);
+    XFree (netStr);
+  }
 } /* END OF FUNCTION ProcessWmIconTitle */
 
 
@@ -4014,3 +3985,57 @@ ProcessMwmHints (ClientData *pCD)
 
 
 } /* END OF ProcessMwmHints */
+
+
+/**
+ * @brief Get the position and size for the maximized window.
+ *
+ * @param pCD
+ * @param pX
+ * @param pY
+ * @param pWidth
+ * @param pHeight
+ */
+void GetMaxInfo (ClientData *pCD, int *pX, int *pY, int *pWidth, int *pHeight)
+{
+    int x, y, width, height;
+    WmHeadInfo_t *WmHI;
+
+    if (pCD->maxConfig)
+    {
+	x      = pCD->maxX;
+	y      = pCD->maxY;
+	width  = pCD->maxWidth;
+	height = pCD->maxHeight;
+    }
+    else if (pCD->fullscreen && !pCD->fullscreenAuto)
+    {
+	x      = pCD->fullscreenX;
+	y      = pCD->fullscreenY;
+	width  = pCD->fullscreenWidth;
+	height = pCD->fullscreenHeight;
+    }
+    else if (WmHI = GetHeadInfo (pCD))
+    {
+	x      = WmHI->x_org;
+	y      = WmHI->y_org;
+	width  = WmHI->width;
+	height = WmHI->height;
+
+	free(WmHI);
+    }
+    else
+    {
+	x      = 0;
+	y      = 0;
+	width  = DisplayWidth (DISPLAY, SCREEN_FOR_CLIENT (pCD));
+	height = DisplayHeight (DISPLAY, SCREEN_FOR_CLIENT (pCD));
+    }
+
+    FrameToClient (pCD, &x, &y, &width, &height);
+
+    if (pX)      *pX      = x;
+    if (pY)      *pY      = y;
+    if (pWidth)  *pWidth  = width;
+    if (pHeight) *pHeight = height;
+}
